about summary refs log tree commit diff
path: root/nixos/modules/system
diff options
context:
space:
mode:
authorNikolay Amiantov <ab@fmap.me>2019-07-25 16:26:28 +0300
committerNikolay Amiantov <ab@fmap.me>2019-08-01 00:55:35 +0300
commitfd405dab3ea0b5a2d3730c836dbcfabf2e820951 (patch)
tree9d204afe7fd57d0de68556b37932664d7d241926 /nixos/modules/system
parentcc9fb5f0152424e96267a30fd9a9ce35837d9f63 (diff)
downloadnixlib-fd405dab3ea0b5a2d3730c836dbcfabf2e820951.tar
nixlib-fd405dab3ea0b5a2d3730c836dbcfabf2e820951.tar.gz
nixlib-fd405dab3ea0b5a2d3730c836dbcfabf2e820951.tar.bz2
nixlib-fd405dab3ea0b5a2d3730c836dbcfabf2e820951.tar.lz
nixlib-fd405dab3ea0b5a2d3730c836dbcfabf2e820951.tar.xz
nixlib-fd405dab3ea0b5a2d3730c836dbcfabf2e820951.tar.zst
nixlib-fd405dab3ea0b5a2d3730c836dbcfabf2e820951.zip
systemd service: rename generator-packages
Diffstat (limited to 'nixos/modules/system')
-rw-r--r--nixos/modules/system/boot/systemd.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/nixos/modules/system/boot/systemd.nix b/nixos/modules/system/boot/systemd.nix
index cf35504e5182..a89a200960e4 100644
--- a/nixos/modules/system/boot/systemd.nix
+++ b/nixos/modules/system/boot/systemd.nix
@@ -497,7 +497,7 @@ in
       '';
     };
 
-    systemd.generator-packages = mkOption {
+    systemd.generatorPackages = mkOption {
       default = [];
       type = types.listOf types.package;
       example = literalExample "[ pkgs.systemd-cryptsetup-generator ]";
@@ -762,10 +762,10 @@ in
 
     environment.etc = let
       # generate contents for /etc/systemd/system-generators from
       # systemd.generators and systemd.generator-packages
       generators = pkgs.runCommand "system-generators" {
           preferLocalBuild = true;
-          packages = cfg.generator-packages;
+          packages = cfg.generatorPackages;
         } ''
         mkdir -p $out
         for package in $packages
@@ -762,10 +762,10 @@ in
     environment.etc = let
       # generate contents for /etc/systemd/system-generators from
-      # systemd.generators and systemd.generator-packages
+      # systemd.generators and systemd.generatorPackages
       generators = pkgs.runCommand "system-generators" {
           preferLocalBuild = true;